@@ -20,6 +20,9 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# CMQ 后台服务错误。
+FAILEDOPERATION_CMQBACKENDERROR = 'FailedOperation.CmqBackendError'
+
 # 创建vpc绑定关系失败。
 FAILEDOPERATION_CREATEBINDVPC = 'FailedOperation.CreateBindVpc'
 
@@ -74,9 +77,6 @@ FAILEDOPERATION_DELETESUBSCRIPTIONS = 'FailedOperation.DeleteSubscriptions'
 # 主题删除失败。
 FAILEDOPERATION_DELETETOPICS = 'FailedOperation.DeleteTopics'
 
-# 查询生产者数据失败。
-FAILEDOPERATION_DESCRIBEPRODUCERS = 'FailedOperation.DescribeProducers'
-
 # 查询订阅数据失败。
 FAILEDOPERATION_DESCRIBESUBSCRIPTION = 'FailedOperation.DescribeSubscription'
 
@@ -116,6 +116,9 @@ FAILEDOPERATION_SENDMESSAGETIMEOUTERROR = 'FailedOperation.SendMessageTimeoutErr
 # 发送消息失败。
 FAILEDOPERATION_SENDMSGFAILED = 'FailedOperation.SendMsgFailed'
 
+# 设置消息保留策略失败。
+FAILEDOPERATION_SETRETENTIONPOLICY = 'FailedOperation.SetRetentionPolicy'
+
 # 设置消息TTL失败。
 FAILEDOPERATION_SETTTL = 'FailedOperation.SetTTL'
 
@@ -149,6 +152,9 @@ INTERNALERROR_BROKERSERVICE = 'InternalError.BrokerService'
 # 获取属性失败。
 INTERNALERROR_GETATTRIBUTESFAILED = 'InternalError.GetAttributesFailed'
 
+# 内部错误。
+INTERNALERROR_ILLEGALMESSAGE = 'InternalError.IllegalMessage'
+
 # 重试可以成功。
 INTERNALERROR_RETRY = 'InternalError.Retry'
 
@@ -224,6 +230,9 @@ RESOURCEINUSE_ENVIRONMENTROLE = 'ResourceInUse.EnvironmentRole'
 # 重名，命名空间已存在。
 RESOURCEINUSE_NAMESPACE = 'ResourceInUse.Namespace'
 
+# 队列已存在。
+RESOURCEINUSE_QUEUE = 'ResourceInUse.Queue'
+
 # 角色已存在。
 RESOURCEINUSE_ROLE = 'ResourceInUse.Role'
 
@@ -266,6 +275,12 @@ RESOURCENOTFOUND_TOPIC = 'ResourceNotFound.Topic'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# 发货异常。
+RESOURCEUNAVAILABLE_CREATEFAILED = 'ResourceUnavailable.CreateFailed'
+
+# 需要充值才可继续操作。
+RESOURCEUNAVAILABLE_FUNDREQUIRED = 'ResourceUnavailable.FundRequired'
+
 # 系统升级。
 RESOURCEUNAVAILABLE_SYSTEMUPGRADE = 'ResourceUnavailable.SystemUpgrade'
 
